@@ -601,11 +601,13 @@ class RabiModel(lmfit.model.Model):
     # pylint: disable=missing-function-docstring
     def guess(
         self, data: NDArray, x: NDArray | None = None, **kws
-    ) -> lmfit.parameter.Parameters | None:
+    ) -> lmfit.parameter.Parameters:
         """Guess parameters for the model."""
         drive_amp = kws.get("drive_amp")
         if drive_amp is None:
-            return None
+            raise ValueError(
+                'Required keyword argument "drive_amp" not provided to guess()'
+            )
 
         amp_guess = abs(max(data) - min(data)) / 2  # amp is positive by convention
         offs_guess = np.mean(data)
@@ -651,7 +653,7 @@ class DecayOscillationModel(lmfit.model.Model):
     # pylint: disable=missing-function-docstring
     def guess(
         self, data: NDArray, x: NDArray | None = None, **kws
-    ) -> lmfit.parameter.Parameters | None:
+    ) -> lmfit.parameter.Parameters:
         """Guess parameters for the model."""
         t = kws.get("t")
         if t is None:
