@@ -202,8 +202,8 @@ def set_ylabel(
 
 
 def set_cbarlabel(
-    cbar: Colorbar, label: str, unit: str | None = None, **kw
-) -> Colorbar:
+    cbar: Colorbar | None, label: str, unit: str | None = None, **kw
+) -> None:
     """
     Add a unit aware z-label to a colorbar object.
 
@@ -219,6 +219,8 @@ def set_cbarlabel(
         keyword argument to be passed to cbar.set_label
 
     """
+    if cbar is None:
+        return
     if unit:
         zticks = cbar.get_ticks()
         precision = 6
