@@ -600,9 +600,9 @@ def flex_colormesh_plot_vs_xy(
 
 # pylint: disable=invalid-name
 def plot_2d_grid(
-    x: list | NDArray,
-    y: list | NDArray,
-    z: float,
+    x: list | NDArray | np.datetime64 | np.timedelta64,
+    y: list | NDArray | np.datetime64 | np.timedelta64,
+    z: list | NDArray,
     xlabel: str,
     xunit: str,
     ylabel: str,
